@@ -1,4 +1,4 @@
-/* @(#) $Id: actsync.c,v 1.18.2.1 1999/03/18 04:17:23 kondou Exp $ */
+/* @(#) $Id: actsync.c,v 1.18.2.2 2000/07/17 02:11:13 rra Exp $ */
 /* @(#) Under RCS control in /usr/local/news/src/inn/local/RCS/actsync.c,v */
 /*
  * actsync - sync or merge two active files
@@ -1436,7 +1436,7 @@ get_active(host, hostid, len, grp, errs)
 	case 'y':
 		/* of COURSE: collabra has incompatible flags. but it	*/
 		/* looks like they can be fixed easily enough.		*/
-		if (cur->type[1] = 'g') {
+		if (cur->type[1] == 'g') {
 			cur->type[1] = '\0';
 		}
 	case 'm':
