@@ -1,4 +1,4 @@
-/*  $Revision: 1.9.2.4 $
+/*  $Revision: 1.9.2.5 $
 **
 **  Read batchfiles on standard input and spew out batches.
 */
@@ -94,8 +94,8 @@ RequeueAndExit(Cookie, line, BytesInArt)
     static char	LINE1[] = "batcher %s times user %.3f system %.3f elapsed %.3f";
     static char	LINE2[] ="batcher %s stats batches %d articles %d bytes %ld";
     static char	NOWRITE[] = "batcher %s cant write spool %s\n";
-    char	temp[BUFSIZ];
-    char	buff[BUFSIZ];
+    char	temp[BIG_BUFFER];
+    char	buff[BIG_BUFFER];
     int		i;
     FILE	*F;
     TIMEINFO	Now;
@@ -219,8 +219,8 @@ main(ac, av)
     TIMEINFO	Now;
     char	*p;
     char	*data;
-    char	line[BUFSIZ];
-    char	buff[BUFSIZ];
+    char	line[BIG_BUFFER];
+    char	buff[BIG_BUFFER];
     long	BytesInArt;
     long	BytesInCB;
     OFFSET_T	Cookie;
