@@ -1,4 +1,4 @@
-/*  $Revision: 1.11.4.1 $
+/*  $Revision: 1.11.4.2 $
 **  Connect to a remote site, and get news from it to offer to our local
 **  server.  Read list on stdin, or get it via NEWNEWS command.  Writes
 **  list of articles still needed to stdout.
@@ -135,6 +135,11 @@ SITEconnect(host)
 	i = NNTPconnect(host, NNTP_PORT, &From, &To, (char *)NULL);
     else {
 	host = innconf->server;
+        if (host == NULL) {
+            fprintf(stderr,
+                    "No server specified and server not set in inn.conf\n");
+            exit(1);
+        }
 	i = NNTPlocalopen(&From, &To, (char *)NULL);
     }
     if (i < 0) {
