@@ -1,4 +1,4 @@
-/*  $Revision: 1.16 $
+/*  $Revision: 1.3 $
 **
 **  A C version of Henry Spencer's "subst" script.
 */
@@ -50,7 +50,7 @@ static char *
 xstrerror()
 {
     extern int	sys_nerr;
-#if !defined(__FreeBSD__) && !defined(__NetBSD__)
+#if !defined(__FreeBSD__) && !defined(__NetBSD__) && !defined(__GLIBC__)
     extern char	*sys_errlist[];
 #endif
     extern int	errno;
@@ -523,6 +523,8 @@ main(ac, av)
 	    ctlfile = optarg;
 	    break;
 	}
+    if (ctlfile == NULL)
+	Usage();
     ac -= optind;
     av += optind;
 
