@@ -1,4 +1,4 @@
-/*  $Revision: 1.1.1.1 $
+/*  $Revision: 1.2 $
 **
 **  Convert date strings and numbers to numbers and strings.
 */
@@ -25,7 +25,7 @@ AllDigits(p)
     register char	*p;
 {
     for (; *p; p++)
-	if (!CTYPE(isdigit, *p))
+	if (!CTYPE(isdigit, (int)*p))
 	    return FALSE;
 	return TRUE;
 }
