@@ -138,7 +138,7 @@
 #define SITE_BUFFER_SIZE	(16 * 1024)
     /* How your DBZ be compiled? Use tagged-hash or splitted tables */
     /* =()<#define @<DBZ_TAGGED_HASH>@_TAGGED_HASH>()= */
-#define DONT_TAGGED_HASH
+#define _TAGGED_HASH
 
 
     /* Function that returns no value, and a pointer to it. */
@@ -239,7 +239,7 @@ typedef int		BOOL;
 */
 
     /* =()<#define @<PERL_SUPPORT>@_PERL>()= */
-#define DO_PERL
+#define DONT_PERL
 
 
 /*
