@@ -1,5 +1,5 @@
 /*
- * $Revision: 1.1.2.2 $
+ * $Revision: 1.1.2.3 $
  */
 
 
@@ -13,11 +13,8 @@
 **  Try to avoid changing these.
 */
 #define RELEASE "2"
-#define PATCHLEVEL "2.2"
-#define DATE "13-Dec-1999"
-#define RELEASE "2"
-#define PATCHLEVEL "2.2"
-#define SUB_PATCHLEVEL_C 1
+#define PATCHLEVEL "2.3"
+#define DATE "18-Jul-2000"
 
 
 /*
