@@ -1,4 +1,4 @@
-/*  $Id: lc.c,v 1.7 1998/06/03 07:22:06 kondou Exp $
+/*  $Id: lc.c,v 1.7.4.1 2000/02/21 13:10:49 kondou Exp $
 **
 **  Routines for the local connect channel.  Create a Unix-domain stream
 **  socket that processes on the local server connect to.  Once the
@@ -38,9 +38,10 @@ LCreader(cp)
 	syslog(L_ERROR, "%s cant accept CCreader %m", LogName);
 	return;
     }
-    new = NCcreate(fd, FALSE, TRUE);
-    new->Address.s_addr = MyAddress.s_addr;
-    syslog(L_NOTICE, "%s connected %d", "localhost", new->fd);
+    if ((new = NCcreate(fd, FALSE, TRUE)) != NULL) {
+	new->Address.s_addr = MyAddress.s_addr;
+	syslog(L_NOTICE, "%s connected %d", "localhost", new->fd);
+    }
 }
 
 
