@@ -1,4 +1,4 @@
-/*  $Id: nc.c,v 1.37.2.9 2000/01/17 13:31:24 kondou Exp $
+/*  $Id: nc.c,v 1.37.2.10 2000/06/09 00:39:14 rra Exp $
 **
 **  Routines for the NNTP channel.  Other channels get the descriptors which
 **  we turn into NNTP channels, and over which we speak NNTP.
@@ -471,7 +471,7 @@ NCihave(CHANNEL *cp)
 	    else cp->Sendid.Size = MAXHEADERSIZE;
 	    cp->Sendid.Data = NEW(char, cp->Sendid.Size);
 	}
-	(void)sprintf(cp->Sendid.Data, "%d %s", NNTP_HAVEIT_VAL, perlrc);
+	(void)sprintf(cp->Sendid.Data, "%d %.200s", NNTP_HAVEIT_VAL, perlrc);
 	NCwritereply(cp, cp->Sendid.Data);
 	DISPOSE(cp->Sendid.Data);
 	cp->Sendid.Size = 0;
