@@ -4,7 +4,7 @@
  * Start Date:  Wed Dec 27 17:10:18 1995
  * Project:     INN (innfeed)
  * File:        misc.c
- * RCSId:       $Id: misc.c,v 1.7 1998/06/11 23:00:19 kondou Exp $
+ * RCSId:       $Id: misc.c,v 1.7.2.1 2000/06/29 22:25:45 rra Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -29,7 +29,7 @@
  */
 
 #if ! defined (lint)
-static const char *rcsid = "$Id: misc.c,v 1.7 1998/06/11 23:00:19 kondou Exp $" ;
+static const char *rcsid = "$Id: misc.c,v 1.7.2.1 2000/06/29 22:25:45 rra Exp $" ;
 static void use_rcsid (const char *rid) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rid) ;
 }
@@ -139,7 +139,7 @@ static void log (int level, const char *fmt, va_list args)
 
   p = malloc (out + 10) ;
   vsprintf (p,fmt,args) ;
-  syslog (level,p) ;
+  syslog (level,"%s",p) ;
 }
 
 void logOrPrint (int level, FILE *fp, const char *fmt, ...)
