@@ -1,4 +1,4 @@
-/*  $Revision: 1.4 $
+/*  $Id: clientlib.c,v 1.4.4.1 2000/06/21 23:31:30 rra Exp $
 **
 **  Routines compatible with the NNTP "clientlib" routines.
 */
@@ -26,7 +26,8 @@ char *getserverbyfile(char *file)
 {
     static char	buff[256];
 
-    (void)strcpy(buff, innconf->server);
+    strncpy(buff, innconf->server, sizeof(buff));
+    buff[255] = '\0';
     return buff;
 }
 
