@@ -1,4 +1,4 @@
-/*  $Revision: 1.4 $
+/*  $Revision: 1.2 $
 **
 */
 #include <stdio.h>
@@ -13,24 +13,14 @@
 **  Send a string of one or more lines down a stdio FILE using RFC977
 **  conventions.  Return -1 on error.
 */
-int
-NNTPsendarticle(p, F, Terminate)
-    register char	*p;
-    register FILE	*F;
-    BOOL		Terminate;
+int NNTPsendarticle(char *p, FILE *F, BOOL Terminate)
 {
-    register char	*next;
-    register char	save;
+    char	        *next;
 
     for (; p && *p; next[-1] = '\n', p = next) {
 	/* Get pointer to next line.  Truncate long lines. */
-	if ((next = strchr(p, '\n')) != NULL) {
+	if ((next = strchr(p, '\n')) != NULL)
 	    *next++ = '\0';
-	    if (next - p > NNTP_STRLEN) {
-		save = p[NNTP_STRLEN - 1];
-		p[NNTP_STRLEN - 1] = '\0';
-	    }
-	}
 
 	/* Write line. */
 	if (*p == '.' && putc('.', F) == EOF)
@@ -41,10 +31,6 @@ NNTPsendarticle(p, F, Terminate)
 	/* Done? */
 	if (next == NULL)
 	    break;
-
-	/* If line was too long, untruncate. */
-	if (next - p > NNTP_STRLEN)
-	    p[NNTP_STRLEN - 1] = save;
     }
 
     if (Terminate && fprintf(F, ".\r\n") == EOF)
