@@ -1,4 +1,4 @@
-/*  $Revision: 1.2 $
+/*  $Revision: 1.3.2.1 $
 **
 */
 #include <stdio.h>
@@ -9,6 +9,12 @@
 #include "nnrpd.h"
 #if	NNRP_LOADLIMIT > 0
 #ifdef linux
+#ifdef HAVE_SYS_SYSINFO_H
+#include <sys/sysinfo.h>
+#else
+/* not all linuces have sys/sysinfo.h -- egil@kvaleberg.no */
+#include <linux/kernel.h>
+#endif
 
 /*
 **  Get the current load average as an integer.
@@ -16,15 +22,12 @@
 int
 GetLoadAverage()
 {
-    FILE *ProcLoadAve;
-    float load;
+    struct sysinfo si;
 
-    if ((ProcLoadAve=fopen("/proc/loadavg", "r"))==NULL)
-        return -1;
-    if (fscanf(ProcLoadAve,"%f", &load)!=1)
-    	return -1;
-    fclose(ProcLoadAve);
-    return (int)(load+0.5);
+    if (sysinfo (&si))
+	return -1;
+
+    return (si.loads[0] + (1 << 15)) >> 16;
 }
 
 #else 
