@@ -1,4 +1,4 @@
-/*  $Revision: 1.28.2.6 $
+/*  $Revision: 1.28.2.7 $
 **
 **  Miscellaneous support routines.
 */
@@ -477,7 +477,7 @@ char *HISgetent(HASH *key, BOOL useoffset, OFFSET_T *off)
     }
     buff[entrysize] = '\0';
     if (strchr(buff, '\n') == NULL) {
-	syslog(L_ERROR, "%s cant find end of line %ld %m", ClientHost, offset);
+	syslog(L_ERROR, "%s cant find end of line %ld", ClientHost, offset);
 	return NULL;
     }
     if (innconf->nnrpdoverstats) {
