@@ -3,13 +3,13 @@
  * Author:      Christophe Wolfhugel <wolf@pasteur.fr>
  *		(although he wouldn't recognise it anymore so don't blame him)
  * File:        perl.c
- * RCSId:       $Id: perl.c,v 1.8.2.1 1999/06/25 03:16:09 kondou Exp $
+ * RCSId:       $Id: perl.c,v 1.8.2.4 2000/06/21 02:43:19 rra Exp $
  * Description: Perl hooks for nnrpd.
  * 
  */
 
 #if ! defined (lint)
-static const char *rcsid = "$Id: perl.c,v 1.8.2.1 1999/06/25 03:16:09 kondou Exp $" ;
+static const char *rcsid = "$Id: perl.c,v 1.8.2.4 2000/06/21 02:43:19 rra Exp $" ;
 static void use_rcsid (const char *rid) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rid) ;
 }
@@ -37,13 +37,7 @@ typedef enum { false = 0, true = 1 } bool;
 #include <EXTERN.h>
 #include <perl.h>
 #include <XSUB.h>
-
-/* Perl 5.004 didn't define ERRSV and PL_na was called na. */
-#ifndef ERRSV
-# define ERRSV GvSV(errgv)
-# define PL_sv_undef sv_undef
-# define PL_na na
-#endif
+#include "ppport.h"
 
 extern BOOL PerlFilterActive;
 extern HEADER	Table[], *EndOfTable;
@@ -109,7 +103,8 @@ char *HandleHeaders(char *article)
           continue;
         }
         s++;
-        hv_store(hdr, p, (s - p) - 1, newSVpv(s, 0), 0);
+        t = (*s == ' ' ? s + 1 : s);
+        hv_store(hdr, p, (s - p) - 1, newSVpv(t, 0), 0);
    }
    /* Store user */
    sv_setpv(perl_get_sv("user",TRUE), PERMuser);
